#
# Conditional build:
%bcond_with	tests	# unit tests
%bcond_with	python2	# CPython 2.x module
%bcond_without	python3	# CPython 3.x module
%bcond_with	doc	# HTML documentation (sphinx-based)

%define		module	pyOpenSSL
Summary:	Python 3 interface to the OpenSSL library
Summary(pl.UTF-8):	Interfejs Pythona 3 do biblioteki OpenSSL
Name:		python3-%{module}
Version:	23.2.0
Release:	1%{?tld}
License:	Apache v2.0
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/pyopenssl/
Source0:	https://files.pythonhosted.org/packages/source/p/pyOpenSSL/%{module}-%{version}.tar.gz
# Source0-md5:	4d716d7cd3d5fe6906b0d1f7536c9f83
URL:		https://github.com/pyca/pyopenssl
%if %(locale -a | grep -q '^C\.utf8$'; echo $?)
BuildRequires:	glibc-localedb-all
%endif
BuildRequires:	python3-devel >= 1:3.6
BuildRequires:	python3-setuptools
%if %{with tests}
BuildRequires:	python3-cryptography >= 38.0.0
BuildRequires:	python3-cryptography < 42
BuildRequires:	python3-flaky
BuildRequires:	python3-pretend
BuildRequires:	python3-pytest >= 3.0.1
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with doc}
BuildRequires:	python3-sphinx_rtd_theme
BuildRequires:	sphinx-pdg-3
%endif
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
High-level wrapper around a subset of the OpenSSL library, includes:
 - SSL.Connection objects, wrapping the methods of Python's portable
   sockets
 - Callbacks written in Python
 - Extensive error-handling mechanism, mirroring OpenSSL's error codes
...and much more.

This package contains Python 3 modules.

%description -l pl.UTF-8
Wysokopoziomowe obudowanie podzbioru biblioteki OpenSSL, zawierające:
 - obiekty SSL.Connection, obudowujący metody przenośnych gniazd
   Pythona
 - wywołania zwrotne napisane w Pythonie
 - obszerny mechanizm obsługi błędów odzwierciedlający kody błędów
   OpenSSL-a
...i wiele więcej.

Ten pakiet zawiera moduły Pythona 3.

%package apidocs
Summary:	API documentation for Python pyOpenSSL module
Summary(pl.UTF-8):	Dokumentacja API modułu Pythona pyOpenSSL
Group:		Documentation

%description apidocs
API documentation for Python pyOpenSSL module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu Pythona pyOpenSSL.

%prep
%setup -q -n %{module}-%{version}

%build
%py3_build

%if %{with tests}
# test_verify_with_time test fails with 32-bit time_t(?)
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
PYTHONPATH=$(pwd)/build-3/lib \
%{__python3} -m pytest -v tests -k 'not test_verify_with_time'
%endif

%if %{with doc}
PYTHONPATH=$(pwd)/build-3/lib \
%{__make} -C doc html \
	SPHINXBUILD=sphinx-build-3
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc CHANGELOG.rst README.rst
%dir %{py3_sitescriptdir}/OpenSSL
%{py3_sitescriptdir}/OpenSSL/*.py
%{py3_sitescriptdir}/OpenSSL/__pycache__
%{py3_sitescriptdir}/pyOpenSSL-%{version}-py*.egg-info

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc doc/_build/html/{*.html,_static,api}
%endif
%changelog
* Tue Apr 02 2024 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/python3-pyOpenSSL.git;a=log;h=master

* Sat Oct 07 2023 Jakub Bogusz <qboosh@pld-linux.org> 3b1d7dd
- updated dependencies, reenabled tests (skipping one)

* Thu Oct 05 2023 Arkadiusz Miśkiewicz <arekm@maven.pl> 506ecc9
- Up to 23.2.0

* Mon Nov 21 2022 Jakub Bogusz <qboosh@pld-linux.org> 2abf804
- updated cryptography dependency, adjusted sphinx

* Mon Nov 21 2022 Arkadiusz Miśkiewicz <arekm@maven.pl> 42e00c7
- Up to 22.1.0

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 31b29d4
- rebuild with tests and docs

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 1740438
- rebuild with python 3.10

* Thu Mar 24 2022 Jan Rękorajski <baggins@pld-linux.org> 2005856
- Release 2 (by relup.sh)

* Thu Mar 10 2022 Jakub Bogusz <qboosh@pld-linux.org> b1b204f
- disable all tests for now

* Wed Mar 09 2022 Jakub Bogusz <qboosh@pld-linux.org> 1ea1f54
- python-pyOpenSSL.spec updated to 22.0.0 for python 3.6+

* Wed Mar 09 2022 Jakub Bogusz <qboosh@pld-linux.org> 36c09cf
- updated to 21.0.0, versioned Obsoletes

* Thu Apr 08 2021 Arkadiusz Miśkiewicz <arekm@maven.pl> 878c381
- up to 20.0.1

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> 3356038
- release 4 (by relup.sh)

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> 48ac708
- release 3 (by relup.sh)

* Wed Mar 18 2020 Jakub Bogusz <qboosh@pld-linux.org> ade2970
- obsolete withdrawn -examples; moved -doc* obsoletes to -apidocs; release 2

* Sat Feb 08 2020 Arkadiusz Miśkiewicz <arekm@maven.pl> aaba16e
- up to 19.1.0

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> c56fee8
- rebuild with python 3.8
- release 2 (by relup.sh)

* Fri Oct 04 2019 Jakub Bogusz <qboosh@pld-linux.org> 04002e8
- updated to 19.0.0

* Wed Dec 05 2018 Jakub Bogusz <qboosh@pld-linux.org> 1bbd18d
- updated download URL

* Mon Nov 05 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 8cf97e1
- up to 18.0.0

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 1ce4936
- release 2 (by relup.sh)

